# bcond default logic is nicely backwards...
%bcond_without tcl
%bcond_with check
%bcond_with icu

%define realname sqlite
%define realver  3490200
%define docver   3490200
%define rpmver   3.49.2

%define major           0
%define libname         %mklibname %{name}_ %{major}
%define develname       %mklibname %{name} -d
%define staticdevelname %mklibname %{name} -d -s

Summary:    C library that implements an embeddable SQL database engine
Name:       sqlite3
Version:    %{rpmver}
Release:    %mkrel 1
License:    Public Domain
Group:      System/Libraries
URL:        https://www.sqlite.org/
Source0:    https://www.sqlite.org/2025/sqlite-src-%{realver}.zip
Source1:    https://www.sqlite.org/2025/sqlite-doc-%{docver}.zip
# Support a system-wide lemon template
Patch0:     sqlite-3.43.1-lemon-system-template.patch
# Temporary workaround for failed percentile test, see patch for details
Patch2:     sqlite-3.8.0-percentile-test.patch
# Disable test date-2.2c on i686
Patch3:     sqlite-3.16-datetest-2.2c.patch
# Modify sync2.test to pass with DIRSYNC turned off
Patch4:     sqlite-3.18.0-sync2-dirsync.patch
BuildRequires:  chrpath
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(readline)
BuildRequires:  glibc-devel
# libdl patch needs
BuildRequires:  autoconf
%if %{with icu}
BuildRequires:  icu-devel
%endif
%if %{with tcl}
BuildRequires:  tcl
BuildRequires:  pkgconfig(tcl)
%{!?tcl_version: %global tcl_version 8.6}
%{!?tcl_sitearch: %global tcl_sitearch %{_libdir}/tcl%{tcl_version}}
%endif

%description
SQLite is a C library that implements an embeddable SQL database
engine. Programs that link with the SQLite library can have SQL
database access without running a separate RDBMS process. The
distribution comes with a standalone command-line access program
(sqlite) that can be used to administer an SQLite database and
which serves as an example of how to use the SQLite library.


%package -n %{libname}
Summary:    C library that implements an embeddable SQL database engine
Group:      System/Libraries
Provides:   sqlite-libs%{?_isa} = %{version}-%{release}

%description -n %{libname}
SQLite is a C library that implements an embeddable SQL database
engine. Programs that link with the SQLite library can have SQL
database access without running a separate RDBMS process. The
distribution comes with a standalone command-line access program
(sqlite) that can be used to administer an SQLite database and
which serves as an example of how to use the SQLite library.

This package contains the shared libraries for %{name}


%package -n %{develname}
Summary:    Development library and header files for the %{name} library
Group:      Development/C
Requires:   %{libname} = %{version}-%{release}
Provides:   libsqlite3-devel%{?_isa} = %{version}-%{release}
Provides:   libsqlite3-devel = %{version}-%{release}
Provides:   sqlite3-devel%{?_isa} = %{version}-%{release}
Provides:   sqlite3-devel = %{version}-%{release}
Provides:   sqlite-devel%{?_isa} = %{version}-%{release}
Provides:   sqlite-devel = %{version}-%{release}

%description -n %{develname}
SQLite is a C library that implements an embeddable SQL database
engine. Programs that link with the SQLite library can have SQL
database access without running a separate RDBMS process. The
distribution comes with a standalone command-line access program
(sqlite) that can be used to administer an SQLite database and
which serves as an example of how to use the SQLite library.

This package contains the static %{libname} library and its header
files.


%package -n %{staticdevelname}
Summary:    Static development library for the %{name} library
Group:      Development/C
Requires:   %{develname} = %{version}-%{release}
Provides:   lib%{name}-static-devel = %{version}-%{release}
Provides:   %{name}-static-devel = %{version}-%{release}

%description -n %{staticdevelname}
SQLite is a C library that implements an embeddable SQL database
engine. Programs that link with the SQLite library can have SQL
database access without running a separate RDBMS process. The
distribution comes with a standalone command-line access program
(sqlite) that can be used to administer an SQLite database and
which serves as an example of how to use the SQLite library.

This package contains the static %{libname} library.


%package    tools
Summary:    Command line tools for managing the %{libname} library
Group:      Databases
Requires:   %{libname} = %{version}-%{release}

%description    tools
SQLite is a C library that implements an embeddable SQL database
engine. Programs that link with the SQLite library can have SQL
database access without running a separate RDBMS process. The
distribution comes with a standalone command-line access program
(sqlite) that can be used to administer an SQLite database and
which serves as an example of how to use the SQLite library.

This package contains command line tools for managing the
%{libname} library.


%package -n lemon
Summary:    A parser generator
Group:      Databases

%description -n lemon
Lemon is an LALR(1) parser generator for C or C++. It does the same
job as bison and yacc. But lemon is not another bison or yacc
clone. It uses a different grammar syntax which is designed to reduce
the number of coding errors. Lemon also uses a more sophisticated
parsing engine that is faster than yacc and bison and which is both
reentrant and thread-safe. Furthermore, Lemon implements features
that can be used to eliminate resource leaks, making is suitable for
use in long-running programs such as graphical user interfaces or
embedded controllers.


%if %{with tcl}
%package    tcl
Summary:    Tcl module for the sqlite3 embeddable SQL database engine
Group:      Development/Other
Requires:   %{name}-tools = %{version}-%{release}
Requires:   tcl >= 1:%{tcl_version}
Provides:   tcl-sqlite3 = %{version}-%{release}

%description    tcl
This package contains the tcl modules for %{name}.
%endif


%prep
%setup -q -a1 -n %{realname}-src-%{realver}
%patch -P0 -p1 -b .lemon-system-template
%patch -P2 -p1
%ifarch %{ix86}
%patch -P3 -p1
%endif
%patch -P4 -p1

%build
export CFLAGS="%{optflags} -DSQLITE_ENABLE_COLUMN_METADATA=1 \
                           -DSQLITE_DISABLE_DIRSYNC=1 \
                           -DSQLITE_ENABLE_FTS3=3 \
                           -DSQLITE_ENABLE_RTREE=1 \
                           -DSQLITE_SECURE_DELETE=1 \
                           -DSQLITE_ENABLE_UNLOCK_NOTIFY=1 \
                           -DSQLITE_ENABLE_DBSTAT_VTAB=1 \
                           -DSQLITE_ENABLE_FTS3_PARENTHESIS=1 \
                           -DSQLITE_ENABLE_JSON1=1 \
                           -DSQLITE_ENABLE_FTS4=1 \
                           -DSQLITE_ENABLE_MATH_FUNCTIONS \
                           -DSQLITE_ENABLE_DBPAGE_VTAB \
                           -DSQLITE_ENABLE_SESSION \
                           -DSQLITE_ENABLE_PREUPDATE_HOOK \
%if %{with icu}
                           -DSQLITE_ENABLE_ICU=1 \
%endif
                           -DSQLITE_ENABLE_LOAD_EXTENSION \
                           -Wall -fno-strict-aliasing"
%if %{with icu}
export LDFLAGS="%{ldflags} $(icu-config --ldflags)"
%endif

# (ovitters) tracker mandates --enable-fts5
# (daviddavid) fossil mandates --enable-fts4
%configure %{!?with_tcl:--disable-tcl} \
           --enable-fts4 \
           --enable-fts5 \
           --enable-threadsafe \
           --enable-load-extension \
           --enable-update-limit \
           --soname=legacy \
           %{?with_tcl:TCLLIBDIR=%{tcl_sitearch}/sqlite3}

%make_build
%if %{with tcl}
%make_build tclextension
%endif

%install
%make_install

install -Dpm0644 sqlite3.1 %{buildroot}%{_mandir}/man1/sqlite3.1
install -Dpm0755 lemon %{buildroot}%{_bindir}/lemon
install -Dpm0644 tool/lempar.c %{buildroot}%{_datadir}/lemon/lempar.c

%if %{with tcl}
mkdir -p %{buildroot}%{tcl_sitearch}/sqlite3/
install -Dpm0755 ./libsqlite%{version}.so %{buildroot}%{tcl_sitearch}/sqlite3/
install -Dpm0644 ./pkgIndex.tcl %{buildroot}%{tcl_sitearch}/sqlite3/
%endif

# This is needed since rpath removal using sed won't work for tcl library for some reason
chrpath --delete %{buildroot}%{tcl_sitearch}/sqlite3/*.so
chrpath --delete %{buildroot}%{_libdir}/*.so.%{version}
chrpath --delete %{buildroot}%{_bindir}/sqlite3

%if %{with check}
%check
%__make test
%endif

%files -n %{libname}
%{_libdir}/lib*.so.%{major}
%{_libdir}/lib*.so.%{version}

%files -n %{develname}
%{_includedir}/*.h
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc

%files -n %{staticdevelname}
%{_libdir}/lib*.a

%files tools
%{_bindir}/sqlite3
%{_mandir}/man1/*

%files -n lemon
%{_bindir}/lemon
%{_datadir}/lemon/

%if %{with tcl}
%files tcl
%{tcl_sitearch}/sqlite3/
%endif


%changelog
* Fri May 09 2025 kekepower <kekepower> 3.49.2-1.mga10
+ Revision: 2182128
- Update to version 3.49.2

* Sat Mar 01 2025 daviddavid <daviddavid> 3.49.1-2.mga10
+ Revision: 2154077
- use "--soname=legacy" configure option to fix libmajor

* Sat Mar 01 2025 daviddavid <daviddavid> 3.49.1-1.mga10
+ Revision: 2154071
- new version: 3.49.1

* Sun Nov 03 2024 wally <wally> 3.47.0-1.mga10
+ Revision: 2112302
- new version 3.47.0

* Sun Nov 03 2024 wally <wally> 3.46.1-3.mga10
+ Revision: 2112267
- add patch to skip RPATH
- add more provides to devel pkg
- provide sqlite-devel

* Thu Aug 15 2024 kekepower <kekepower> 3.46.1-2.mga10
+ Revision: 2086697
- Update to version 3.46.1

* Tue Apr 16 2024 kekepower <kekepower> 3.45.3-2.mga10
+ Revision: 2058065
- Update to version 3.45.3

* Fri Apr 05 2024 wally <wally> 3.45.2-2.mga10
+ Revision: 2054685
- basesystem rebuild for i686

* Tue Mar 12 2024 kekepower <kekepower> 3.45.2-1.mga10
+ Revision: 2049492
- Update to version 3.45.2

* Sun Feb 18 2024 wally <wally> 3.45.1-2.mga10
+ Revision: 2042444
- provide sqlite-libs with lib pkg

* Sat Feb 17 2024 kekepower <kekepower> 3.45.1-1.mga10
+ Revision: 2042070
- Update to version 3.45.1

* Fri Jan 19 2024 danf <danf> 3.45.0-2.mga10
+ Revision: 2032210
- Rebuild for missing RPM

* Thu Jan 18 2024 kekepower <kekepower> 1.mga10-current
+ Revision: 2031981
- Update to version 3.45.0

* Sat Nov 25 2023 kekepower <kekepower> 3.44.2-1.mga10
+ Revision: 2009521
- Update to version 3.44.2

* Thu Nov 23 2023 kekepower <kekepower> 3.44.1-1.mga10
+ Revision: 2009325
- Update to version 3.44.1

* Tue Oct 10 2023 kekepower <kekepower> 3.43.2-1.mga10
+ Revision: 1994185
- Update to version 3.43.2

* Mon Sep 25 2023 wally <wally> 3.43.1-1.mga10
+ Revision: 1990892
- new version 3.43.1
- drop old obsoletes
- add support for LIMIT on UPDATE and DELETE statements

* Wed Dec 28 2022 kekepower <kekepower> 3.40.1-1.mga9
+ Revision: 1927458
- Update to version 3.40.1

* Wed Nov 16 2022 kekepower <kekepower> 3.40.0-1.mga9
+ Revision: 1908078
- Update to version 3.40.0

* Fri Sep 30 2022 kekepower <kekepower> 3.39.4-1.mga9
+ Revision: 1893412
- Update to version 3.39.4

* Tue Sep 06 2022 kekepower <kekepower> 3.39.3-1.mga9
+ Revision: 1884488
- Update to version 3.39.3

* Fri Jul 22 2022 kekepower <kekepower> 3.39.2-1.mga9
+ Revision: 1870086
- Update to version 3.39.2

* Thu Jul 14 2022 kekepower <kekepower> 3.39.1-1.mga9
+ Revision: 1868758
- Update to version 3.39.1

* Sun Jun 26 2022 kekepower <kekepower> 3.39.0-1.mga9
+ Revision: 1866327
- Update to version 3.39.0

* Thu Jun 09 2022 tv <tv> 3.38.5-2.mga9
+ Revision: 1863716
- Build w/o icu. Since rpm uses sqlite, this bloats minimal install

* Fri May 06 2022 kekepower <kekepower> 3.38.5-1.mga9
+ Revision: 1856548
- Update to version 3.38.5

* Wed May 04 2022 kekepower <kekepower> 3.38.4-1.mga9
+ Revision: 1856203
- Update to version 3.38.4

* Wed Apr 27 2022 kekepower <kekepower> 3.38.3-1.mga9
+ Revision: 1854679
- Update to version 3.38.3

* Sat Mar 26 2022 kekepower <kekepower> 3.38.2-1.mga9
+ Revision: 1828638
- Update to version 3.38.2

* Thu Mar 24 2022 umeabot <umeabot> 3.38.1-3.mga9
+ Revision: 1824083
- Mageia 9 Mass Rebuild

* Sat Mar 12 2022 kekepower <kekepower> 3.38.1-2.mga9
+ Revision: 1790615
- Update to version 3.38.1

* Sat Feb 26 2022 guillomovitch <guillomovitch> 3.38.0-2.mga9
+ Revision: 1785448
- rebuild with extension loading enabled

* Wed Feb 23 2022 kekepower <kekepower> 3.38.0-1.mga9
+ Revision: 1783574
- Update to version 3.38.0

* Fri Jan 07 2022 luigiwalser <luigiwalser> 3.37.2-1.mga9
+ Revision: 1767257
- 3.37.2

* Fri Dec 31 2021 kekepower <kekepower> 3.37.1-1.mga9
+ Revision: 1765560
- Update to version 3.37.1

* Sat Nov 27 2021 kekepower <kekepower> 3.37.0-1.mga9
+ Revision: 1759713
- Update to version 3.37.0

* Tue Aug 03 2021 luigiwalser <luigiwalser> 3.36.0-2.mga9
+ Revision: 1738973
- rebuild for icu

* Tue Aug 03 2021 luigiwalser <luigiwalser> 3.36.0-1.mga9
+ Revision: 1738730
- 3.36.0

* Mon Apr 19 2021 kekepower <kekepower> 3.35.5-1.mga9
+ Revision: 1717219
- Update to version 3.35.5

* Fri Apr 02 2021 kekepower <kekepower> 3.35.4-1.mga9
+ Revision: 1712850
- Update to version 3.35.4

* Fri Mar 26 2021 kekepower <kekepower> 3.35.3-1.mga9
+ Revision: 1710787
- Update to version 3.35.3

* Sun Mar 21 2021 daviddavid <daviddavid> 3.35.2-1.mga9
+ Revision: 1706537
- new version: 3.35.2

* Wed Mar 17 2021 daviddavid <daviddavid> 3.35.1-1.mga9
+ Revision: 1704018
- new version: 3.35.1

* Fri Mar 12 2021 kekepower <kekepower> 3.35.0-1.mga9
+ Revision: 1701838
- Update to version 3.35.0

* Wed Jan 20 2021 kekepower <kekepower> 3.34.1-1.mga8
+ Revision: 1672703
- Update to version 3.34.1

* Wed Dec 02 2020 shlomif <shlomif> 3.34.0-1.mga8
+ Revision: 1651724
- New version 3.34.0

* Mon Nov 30 2020 luigiwalser <luigiwalser> 3.33.0-2.mga8
+ Revision: 1650929
- rebuild for icu

* Mon Aug 17 2020 shlomif <shlomif> 3.33.0-1.mga8
+ Revision: 1614553
- New version 3.33.0

* Wed Jul 01 2020 wally <wally> 3.32.3-2.mga8
+ Revision: 1601067
- rebuild for icu 67.1

* Fri Jun 19 2020 shlomif <shlomif> 3.32.3-1.mga8
+ Revision: 1596628
- New version 3.32.3

* Sat Jun 06 2020 shlomif <shlomif> 3.32.2-1.mga8
+ Revision: 1590781
- New version 3.32.2

* Wed May 27 2020 shlomif <shlomif> 3.32.1-1.mga8
+ Revision: 1588143
- New version 3.32.1

* Sat May 23 2020 neoclust <neoclust> 3.32.0-1.mga8
+ Revision: 1587124
- New version 3.32.0

* Sat Apr 04 2020 wally <wally> 3.31.1-4.mga8
+ Revision: 1564502
- rebuild for new icu 66.1

* Thu Feb 20 2020 umeabot <umeabot> 3.31.1-3.mga8
+ Revision: 1545291
- Mageia 8 Mass Rebuild

* Tue Jan 28 2020 tv <tv> 3.31.1-2.mga8
+ Revision: 1484342
- new release
- Remove stupid-openfiles-test patch as the upstream test now
  work properly even on systems with larger number of file descriptors
  Related: https://sqlite.org/src/info/a27b0b880d76c683

* Thu Jan 23 2020 shlomif <shlomif> 3.31.0-1.mga8
+ Revision: 1482466
- New version 3.31.0
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Jan 04 2020 luigiwalser <luigiwalser> 3.30.1-3.mga8
+ Revision: 1476016
- rebuild for readline

* Mon Oct 28 2019 daviddavid <daviddavid> 3.30.1-2.mga8
+ Revision: 1456171
- enable the FTS4 extension (needed for fossil >= 2.10)

* Sat Oct 12 2019 daviddavid <daviddavid> 3.30.1-1.mga8
+ Revision: 1452309
- new version: 3.30.1

* Sat Oct 05 2019 daviddavid <daviddavid> 3.29.0-3.mga8
+ Revision: 1449444
- rebuild for new icu 65.1

* Sat Aug 31 2019 wally <wally> 3.29.0-2.mga8
+ Revision: 1435835
- enable JSON1 extension (for sqlalchemy)

* Tue Jul 16 2019 kekepower <kekepower> 3.29.0-1.mga8
+ Revision: 1421820
- Update to version 3.29.0
- Rediff Patch2

* Wed Apr 17 2019 kekepower <kekepower> 3.28.0-1.mga7
+ Revision: 1391960
- Update to version 3.28.0

* Mon Feb 25 2019 kekepower <kekepower> 3.27.2-1.mga7
+ Revision: 1370192
- Update to version 3.27.2

* Fri Feb 08 2019 kekepower <kekepower> 3.27.1-1.mga7
+ Revision: 1364307
- Update to version 3.27.1

* Fri Feb 08 2019 kekepower <kekepower> 3.27.0-1.mga7
+ Revision: 1364096
- Update to version 3.27.0
- Update Source URLs

* Sat Dec 29 2018 luigiwalser <luigiwalser> 3.26.0-2.mga7
+ Revision: 1346116
- rebuild for icu

* Mon Dec 10 2018 kekepower <kekepower> 3.26.0-1.mga7
+ Revision: 1339685
- Update to version 3.26.0

* Sun Oct 14 2018 shlomif <shlomif> 3.25.2-1.mga7
+ Revision: 1320314
- New version 3.25.2.
- disable tests due to 4 failing scripts.

* Sun Sep 23 2018 umeabot <umeabot> 3.24.0-3.mga7
+ Revision: 1301155
- Mageia 7 Mass Rebuild

* Mon Aug 20 2018 tv <tv> 3.24.0-2.mga7
+ Revision: 1252946
- rebuild for new libicu

* Fri Jun 22 2018 shlomif <shlomif> 3.24.0-1.mga7
+ Revision: 1238829
- New version 3.24.0 - reenable tests

* Thu May 24 2018 shlomif <shlomif> 3.23.1-2.mga7
+ Revision: 1232071
- Rebuild for new glibc to hopefully fix kactivity

* Wed Apr 11 2018 kekepower <kekepower> 3.23.1-1.mga7
+ Revision: 1217465
- Update to version 3.23.1

* Mon Apr 02 2018 kekepower <kekepower> 3.23.0-1.mga7
+ Revision: 1214730
- Update to version 3.23.0
- Remove patch applied upstream

* Sat Mar 17 2018 luigiwalser <luigiwalser> 3.22.0-3.mga7
+ Revision: 1210150
- add upstream patch to fix CVE-2018-8740

* Wed Mar 07 2018 shlomif <shlomif> 3.22.0-2.mga7
+ Revision: 1207143
- New version 3.22.0

* Fri Dec 29 2017 wally <wally> 3.21.0-2.mga7
+ Revision: 1187014
- rebuild for new icu

* Sat Oct 28 2017 tv <tv> 3.21.0-1.mga7
+ Revision: 1174361
- new release

* Sat Oct 28 2017 tv <tv> 3.20.1-1.mga7
+ Revision: 1174355
- new release

* Tue Aug 22 2017 ovitters <ovitters> 3.20.0-2.mga7
+ Revision: 1143081
- use --enable-fts5 as required by tracker

* Mon Aug 07 2017 tv <tv> 3.20.0-1.mga7
+ Revision: 1138487
- new release
- fix sources URL
- resync patches with FC

* Sun Jul 30 2017 luigiwalser <luigiwalser> 3.17.0-3.mga7
+ Revision: 1132643
- rediff patch from google chrome to fix CVE-2017-7000

* Wed Mar 15 2017 mrambo3501 <mrambo3501> 3.17.0-2.mga6
+ Revision: 1092808
- Rebuild for icu-58.2

* Wed Mar 01 2017 mrambo3501 <mrambo3501> 3.17.0-1.mga6
+ Revision: 1088370
- update to version 3.17.0

* Wed Nov 09 2016 tv <tv> 3.14.2-5.mga6
+ Revision: 1066102
- drop merged patch
- new release

* Thu Jul 07 2016 luigiwalser <luigiwalser> 3.12.2-3.mga6
+ Revision: 1039481
- add upstream patch to fix CVE-2016-6153

* Fri May 13 2016 shlomif <shlomif> 3.12.2-2.mga6
+ Revision: 1014899
- Rebuild for new ICU

* Tue Apr 19 2016 luigiwalser <luigiwalser> 3.12.2-1.mga6
+ Revision: 1003625
- 3.12.2

* Sat Apr 09 2016 shlomif <shlomif> 3.12.1-1.mga6
+ Revision: 999831
- New version 3.12.1.
- Upgrading it will hopefully fix the tests of sqlalchemy - see:
- https://bitbucket.org/zzzeek/sqlalchemy/issues/3688

* Wed Mar 30 2016 tv <tv> 3.12.0-1.mga6
+ Revision: 996815
- new release

* Fri Mar 04 2016 luigiwalser <luigiwalser> 3.11.1-1.mga6
+ Revision: 985282
- 3.11.1

* Thu Feb 18 2016 tv <tv> 3.11.0-1.mga6
+ Revision: 967327
- fix d/l URL
- 3.11.0
- 3.11.0

* Fri Jan 01 2016 luigiwalser <luigiwalser> 3.9.2-2.mga6
+ Revision: 917922
- rebuild for icu

* Fri Nov 06 2015 fwang <fwang> 3.9.2-1.mga6
+ Revision: 898048
- 3.9.2

* Sat Oct 17 2015 fwang <fwang> 3.9.1-1.mga6
+ Revision: 892301
- 3.9.1

* Fri Sep 25 2015 luigiwalser <luigiwalser> 3.8.11.1-2.mga6
+ Revision: 883584
- enable icu support (mga#16814)

* Sun Sep 06 2015 fwang <fwang> 3.8.11.1-1.mga6
+ Revision: 873387
- 3.8.11.1

* Fri Aug 21 2015 tmb <tmb> 3.8.11-3.mga6
+ Revision: 867739
- rebuild for new gcc

* Fri Aug 14 2015 tv <tv> 3.8.11-2.mga6
+ Revision: 864598
- enable SQLITE_ENABLE_DBSTAT_VTAB for firefox-beta

* Tue Jul 28 2015 fwang <fwang> 3.8.11-1.mga6
+ Revision: 858380
- 3.8.11

* Sat May 23 2015 luigiwalser <luigiwalser> 3.8.10.2-1.mga5
+ Revision: 822667
- 3.8.10.2

* Sun May 10 2015 luigiwalser <luigiwalser> 3.8.10.1-1.mga5
+ Revision: 821636
- 3.8.10.1
- 3.8.10

* Thu Apr 23 2015 luigiwalser <luigiwalser> 3.8.9-1.mga5
+ Revision: 820588
- 3.8.9

* Fri Jan 16 2015 tv <tv> 3.8.7.4-2.mga5
+ Revision: 810991
- submit to core/release

* Thu Jan 15 2015 tv <tv> 3.8.7.4-1.mga5
+ Revision: 810855
- 3.8.7.4

* Wed Oct 15 2014 umeabot <umeabot> 3.8.6-3.mga5
+ Revision: 747965
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.8.6-2.mga5
+ Revision: 689302
- Mageia 5 Mass Rebuild

* Sun Aug 17 2014 fwang <fwang> 3.8.6-1.mga5
+ Revision: 664879
- 3.8.6

* Thu Jun 05 2014 fwang <fwang> 3.8.5-1.mga5
+ Revision: 633333
- 3.8.5

* Fri Apr 04 2014 fwang <fwang> 3.8.4.3-1.mga5
+ Revision: 611615
- 3.8.4.3

* Mon Mar 31 2014 fwang <fwang> 3.8.4.2-1.mga5
+ Revision: 610759
- 3.8.4.2

* Wed Mar 12 2014 fwang <fwang> 3.8.4.1-1.mga5
+ Revision: 602576
- 3.8.4.1

* Tue Mar 11 2014 fwang <fwang> 3.8.4-1.mga5
+ Revision: 601996
- 3.8.4

* Wed Feb 12 2014 fwang <fwang> 3.8.3.1-1.mga5
+ Revision: 589588
- 3.8.3.1

* Tue Feb 04 2014 fwang <fwang> 3.8.3-2.mga5
+ Revision: 581614
- new version 3.8.3

* Sat Oct 19 2013 umeabot <umeabot> 3.8.0.2-2.mga4
+ Revision: 533740
- Mageia 4 Mass Rebuild

* Wed Sep 04 2013 fwang <fwang> 3.8.0.2-1.mga4
+ Revision: 475011
- new version 3.8.0.2

* Fri Aug 30 2013 fwang <fwang> 3.8.0.1-1.mga4
+ Revision: 473194
- new version 3.8.0.1

* Tue Aug 27 2013 fwang <fwang> 3.8.0-1.mga4
+ Revision: 472195
- new version 3.8.0

* Thu May 23 2013 fwang <fwang> 3.7.17-1.mga4
+ Revision: 424794
- new version 3.7.17

* Mon Apr 01 2013 fwang <fwang> 3.7.16.1-1.mga3
+ Revision: 406916
- new version 3.7.16.1

* Tue Mar 19 2013 fwang <fwang> 3.7.16-1.mga3
+ Revision: 404048
- new version 3.7.16

* Mon Jan 14 2013 umeabot <umeabot> 3.7.15.2-2.mga3
+ Revision: 382558
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jan 11 2013 kamil <kamil> 3.7.15.2-1.mga3
+ Revision: 344933
- new Patch version 3.7.15.2

* Fri Dec 21 2012 fwang <fwang> 3.7.15.1-1.mga3
+ Revision: 333563
- new version 3.7.15.1

* Sun Dec 16 2012 fwang <fwang> 3.7.15-1.mga3
+ Revision: 331624
- new version 3.7.15

* Fri Dec 14 2012 spuhler <spuhler> 3.7.14.1-2.mga3
+ Revision: 330659
- bumped rel so it will upgrade from mga2 rel 1.1

* Sun Oct 07 2012 fwang <fwang> 3.7.14.1-1.mga3
+ Revision: 303121
- new version 3.7.14.1
- use configure2_5x

* Tue Sep 04 2012 fwang <fwang> 3.7.14-1.mga3
+ Revision: 287807
- new version 3.7.14

* Mon Jul 23 2012 shlomif <shlomif> 3.7.13-2.mga3
+ Revision: 273747
- Fix crashes with libsqlite and MALLOC_CHECK_=1

* Tue Jun 12 2012 fwang <fwang> 3.7.13-1.mga3
+ Revision: 259925
- new version 3.7.13

* Mon May 28 2012 fwang <fwang> 3.7.12.1-1.mga3
+ Revision: 247648
- new version 3.7.12.1

* Wed May 09 2012 kamil <kamil> 3.7.11-1.mga2
+ Revision: 234984
- new version 3.7.11

* Tue Jan 17 2012 fwang <fwang> 3.7.10-1.mga2
+ Revision: 197146
- drop unapplied patches
- new version 3.7.10

* Mon Nov 21 2011 fwang <fwang> 3.7.9-2.mga2
+ Revision: 170361
- drop .la files

* Wed Nov 02 2011 fwang <fwang> 3.7.9-1.mga2
+ Revision: 161234
- new version 3.7.9

* Tue Sep 20 2011 fwang <fwang> 3.7.8-1.mga2
+ Revision: 145906
- fix group
- new version 3.7.8

* Sun Jul 17 2011 fwang <fwang> 3.7.7.1-5.mga2
+ Revision: 125275
- rebuild for new tcl

* Mon Jul 04 2011 dmorgan <dmorgan> 3.7.7.1-4.mga2
+ Revision: 118377
- Fix requires
- Fix tcl version

* Mon Jul 04 2011 misc <misc> 3.7.7.1-2.mga2
+ Revision: 117903
- rebuild for tcl
- clean old architecture conditional

* Wed Jun 29 2011 fwang <fwang> 3.7.7.1-1.mga2
+ Revision: 115607
- new version 3.7.7.1

* Sat Jun 25 2011 dmorgan <dmorgan> 3.7.7-3.mga2
+ Revision: 113776
- Update doc source

* Fri Apr 29 2011 dmorgan <dmorgan> 3.7.6.2-3.mga1
+ Revision: 93459
- Fix requires

* Fri Apr 29 2011 dmorgan <dmorgan> 3.7.6.2-2.mga1
+ Revision: 93441
- Add lemon subpackage ( fedora )
  Add tcl subpackage ( fedora )
  Add check ( fedora )

* Mon Apr 18 2011 tv <tv> 3.7.6.2-1.mga1
+ Revision: 87588
- new release

* Wed Apr 13 2011 tv <tv> 3.7.6.1-1.mga1
+ Revision: 84630
- new release

* Wed Apr 13 2011 tv <tv> 3.7.6-1.mga1
+ Revision: 84500
- new release

* Tue Feb 01 2011 dmorgan <dmorgan> 3.7.5-1.mga1
+ Revision: 46088
- New version

* Sat Jan 29 2011 dmorgan <dmorgan> 3.7.4-1.mga1
+ Revision: 43429
- Sync with mdv package

* Sat Jan 08 2011 blino <blino> 3.7.3-2.mga1
+ Revision: 971
- remove old ldconfig scriptlets and tcl path
- imported package sqlite3

